==> oapi-sdk-2.0.0-rc6-sources.jar: com/lark/oapi/core/request/FormData.java <==
/*
 * MIT License
 *
 * Copyright (c) 2022 Lark Technologies Pte. Ltd.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice, shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.lark.oapi.core.request;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class FormData {

  private final Map<String, Object> params;
  private final List<FormDataFile> files;

  public FormData() {
    this.params = new HashMap<>();
    this.files = new ArrayList<>();
  }

  public Map<String, Object> getParams() {
    return params;
  }

  public List<FormDataFile> getFiles() {
    return files;
  }

  public void addFile(String field, FormDataFile file) {
    file.setFieldName(field);
    this.files.add(file);
  }

  public void addField(String field, Object val) {
    this.params.put(field, val);
  }

}

==> oapi-sdk-2.0.3-sources.jar: com/lark/oapi/core/request/FormData.java <==
/*
 * MIT License
 *
 * Copyright (c) 2022 Lark Technologies Pte. Ltd.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice, shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.lark.oapi.core.request;

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class FormData {

  private final Map<String, Object> params;
  private final List<FormDataFile> files;

  public FormData() {
    this.params = new HashMap<>();
    this.files = new ArrayList<>();
  }

  public Map<String, Object> getParams() {
    return params;
  }

  public List<FormDataFile> getFiles() {
    return files;
  }

  public void addFile(String field, FormDataFile file) {
    file.setFieldName(field);
    this.files.add(file);
  }

  public void addFile(String field, File file) {
    FormDataFile formDataFile = new FormDataFile();
    formDataFile.setFileName(field);
    formDataFile.setFile(file);
    this.files.add(formDataFile);
  }

  public void addField(String field, Object val) {
    this.params.put(field, val);
  }

}
